放牛班的春天 (豆瓣)
Description: 放牛班的春天电影简介和剧情介绍,放牛班的春天影评、图片、预告片、影讯、论坛、在线购票
Keywords: 放牛班的春天,Les choristes,放牛班的春天影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.16豆瓣电影Top250

# 放牛班的春天 Les choristes (2004)

更新描述或海报

导演: 克里斯托夫·巴拉蒂
编剧: 乔治·沙普罗 / 勒·惠勒 / 诺埃-诺尔 / 克里斯托夫·巴拉蒂 / 菲利普·洛佩斯-屈瓦尔
主演: 让-巴蒂斯特·莫尼耶 / 热拉尔·朱尼奥 / 弗朗索瓦·贝莱昂 / 凯德·麦拉德 / 让-保罗·博奈雷 / 雅克·贝汉 / 玛丽·布奈尔 / 马克桑斯·贝汉 / 格雷戈里·加迪诺尔 / 托马斯·布伦门塔尔 / 西里尔·伯尔尼科特 / 西蒙·法戈特 / 泰奥杜尔·卡雷-卡赛尼 / 菲利普·杜·詹纳兰德 / 埃里克·德斯玛莱茨 / 狄迪尔·弗拉蒙 / Carole Weiss
类型: 剧情 / 音乐
制片国家/地区: 法国 / 瑞士 / 德国
语言: 法语
上映日期: 2004-10-16(中国大陆) / 2022-12-02(中国大陆重映) / 2004-03-17(法国)
片长: 97分钟
又名: 歌声伴我心(港) / 唱诗班男孩 / The Chorus
IMDb: tt0372824
豆瓣评分
引用
9.3
1239597人评价
5星
70.8%
4星
25.5%
3星
3.5%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
8.0
2人评价
好于 99% 音乐片
好于 99% 剧情片
想看 看过
评价:
推荐

## 放牛班的春天的剧情简介 · · · · · ·

1949年的法国乡村，音乐家克莱门特（热拉尔·朱尼奥 饰）到了一间外号叫“塘低”的男子寄宿学校当助理教师。学校里的学生大部分都是难缠的问题儿童，体罚在这里司空见惯，学校的校长（弗朗索瓦·贝莱昂 饰）只顾自己的前途，残暴高压。
性格沉静的克莱门特尝试用自己的方法改善这种状况，他重新创作音乐作品，组织合唱团，决定用音乐的方法来打开学生们封闭的心灵。
然而，事情并不顺利，克莱门特发现学生皮埃尔·莫安琦（让-巴蒂斯特·莫尼耶 饰）拥有非同一般的音乐天赋，但是单亲家庭长大的他，性格异常敏感孤僻，怎样释放皮埃尔的音乐才能，让克莱门特头痛不已；同时，他与皮埃尔母亲的感情也渐渐微妙起来。 ©豆瓣

## 放牛班的春天的演职员 · · · · · · ( 全部 29 )

- 克里斯托夫·巴拉蒂 导演
- 让-巴蒂斯特·莫尼耶 饰 Pierre Morhange
- 热拉尔·朱尼奥 饰 Clément Mathieu
- 弗朗索瓦·贝莱昂 饰 Headmaster Rachin
- 凯德·麦拉德 饰 Chabert
- 让-保罗·博奈雷 饰 La Père Maxence

## 放牛班的春天的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片562 · 添加 )

## 放牛班的春天的获奖情况 · · · · · · ( 全部 )

- 第77届奥斯卡金像奖
- 最佳外语片(提名)
- 克里斯托夫·巴拉蒂

- 第62届金球奖
- 电影类 最佳外语片(提名)

- 第58届英国电影学院奖
- 电影奖 最佳改编剧本(提名)
- 菲利普·洛佩斯-屈瓦尔 / 克里斯托夫·巴拉蒂

## 喜欢这部电影的人也喜欢 · · · · · ·

  海上钢琴师

  音乐之声

  爆裂鼓手

  肖申克的救赎

  阿甘正传

  波西米亚狂想曲

  当幸福来敲门

  曾经

  再次出发之纽约遇见你

  三傻大闹宝莱坞

我要写短评

## 放牛班的春天的短评 · · · · · · ( 全部 215114 条 )

热门 / 最新 / 好友

### 7005 有用 亂馬2/1 看过 2010-07-17 21:29:31

那漫天飘扬的纸飞机是我对你最诚挚的敬意。

### 9555 有用 高歌 看过 2008-08-01 23:04:18

纸飞机+挥动的小手——那一刻，什么都值了

### 7498 有用 沈书君 看过 2008-10-06 09:33:32

一个孩子在启蒙时期，能够遇到一位好的老师，真的是一件非常幸运的事情。

### 5235 有用 Jumpingtigger 看过 2012-07-05 23:46:31

星期六，贝贝抱着小熊跟马修老师回家了！QwQ

### 2285 有用 Q。 看过 2008-05-18 09:04:13

这是一次心灵的洗礼，没人生本向恶，只是无情的手把人推向了无尽的深渊。Morhange每一次天使般的独唱，总让我感动的浑身直起鸡皮疙瘩，特别是那纸飞机从窗口飞出，“感谢、再见”的小手一挥，那份感动，不言而喻。而最重要的，看这部电影不仅是好“看”，天籁的童声更是听觉的享受。★★★★☆

> 更多短评 215114条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 LLudeer 看过 2018-10-24 09:27:12

满满感动

我要写影评

## 放牛班的春天的影评 · · · · · · ( 全部 3552 条 )

热门 / 最新 / 好友
小小风也 2007-02-25 08:25:47

## 唱一首歌

描写老师和孩子们关系的影片很多，感人的也不少，在电影＜放牛班的春天＞里，辅读学校的孩子们被新来的学监兼音乐老师马修先生吸引，爱上了音乐爱上了合唱。事后我发现，观看这部电影的过程是一个纯私人事件。 我就读的的初级中学曾经非常烂，它座落在市郊结合部。当时没有公共... (展开)
3288 218 318回应 收起
甘蓝 2006-01-09 13:58:42

## 从教育心理学的角度来扯几句

其实观影之前，看它的剧照已经可以隐约嗅出一丝《春风化雨》（《死亡诗社》）的气息来。一群顽劣成性的学生，一位充满爱心，循循善诱的教师，再加上一个或几个顽固不化，粗暴专制的学校领导——这样的人物组合几乎已经形成了教育题材电影的一个固定的内在结构——所以有人说这... (展开)
1891 72 107回应 收起
豆友1144637 2006-04-23 02:42:02

## 嘴角漾笑

《Les Choristes》，“放牛班的春天”，名字译得很巧妙，单是读着都漾出善意的笑。朴素流畅的影片，连颜色都很节省，尽是饱和度很接近的灰，让眼睛保存着气力帮助嘴角表露快乐或悲伤。 真诚的电影总是能牢牢抓着你，声色具备的100多分钟后，灵魂才还给自己，任由你品评褒贬，... (展开)
1916 133 179回应 收起
夭夭&吹泡泡的鱼 2008-11-09 19:29:14

## 傻孩子的星期六

每天，都会有颗傻乎乎的脑袋爬在铁门上向外张望，等待星期六、等待他已经战死的父亲、等待那个能带他离开的人。 机缘巧合，看过好几次《放牛班的春天》，每每为它感动。和朋友探讨，很多人喜欢马修，喜欢他把春天带给了这个被美好遗忘的角落，喜欢他用音乐还原了孩子纯洁的心灵... (展开)
1649 27 94回应 收起
贵宝弟 2007-03-08 19:37:34

## 一个自私孩子的美梦

其实我很喜欢看电影，但是总有些把电影当《故事会》看的感觉，或笑或哭，或感动，或郁闷的跟着镜头进入别人的生活个把钟头后，关机，继续自己无聊的日子。并没有想过去写下那些电影带给我的思考。最近突然有了冲动，想细细的品味一下那些美丽的画面后留给自己的感动。不为什么... (展开)
632 73 130回应 收起
离离塬上草 2016-12-27 09:37:52

## 第三次看《放牛班》，觉得蒙丹并非我们以为的坏孩子

《放牛班的春天》看完第三遍了。其实这一次里，给我感受最深的不是马修，也不是莫翰奇，而是蒙丹。 一直以来，我都对蒙丹这个孩子的存在意义感到奇怪，第一第二次看的时候，留给我的影响大概就是反面教材的坏孩子吧？甚至第一遍我没看仔细，直到最后还以为是蒙丹偷了院长的钱。... (展开)
317 25 128回应 收起
笙笙不兮看电影 2019-03-04 22:20:37 #《放牛班的春天》是如何治愈你的？

## 《放牛班的春天》是如何治愈你的？

这篇影评可能有剧透

《放牛班的春天》：池塘畔底有天使 01 《放牛班的春天》是我每次观看必泪奔的一部电影。 没有超高颜值的演员，没有跌宕起伏的剧情反转，没有浓墨重彩的感情戏，甚至全片只出现了两位女演员，连学生都是清一色的小男孩。 然而，就是这么一部色彩饱和度极低，连名字都翻译得颇显... (展开)
569 1 24回应 收起
何必问情 2019-04-04 23:31:01

## 蒙丹烧了学校？老师到底带孩子们去了哪里？

这篇影评可能有剧透

看到最后，特别想知道，老师带着孩子们去了哪里。 可惜导演并没有直接告诉我们。 然后一个镜头，蒙丹看着学校，抽着烟。 什么意思呢？这个人物铺陈那么多，是什么作用呢？在60名孩子的群像中，一个唱歌最好的、一个最小的、一个蒙丹，三个人占的篇幅最大（其他次重要人物包括让... (展开)
366 4 76回应 收起
小痕呀 2017-05-14 11:13:36

## “池塘之底”有天使

这篇影评可能有剧透

那群唱诗班的小天使，洗涤了我的心灵。 对于里面的角色只有喜欢和更喜欢之分。 佩皮诺不可爱吗？ 莫杭治的蓝眼睛没有魅力吗？ 克莱门特马修这样的老师不可敬吗？ 喜欢这部电影，是因为它复杂，是因为它多面立体且真实。没有一个小孩子生下来就是邪恶的，打骂和体罚只会让他们的... (展开)
175 4 11回应 收起
工藤新一的猴子 2017-05-12 11:40:45

## 有关马修老师和莫杭治的母亲

马修老师喜欢莫杭治母亲这段恋情，可能大家都觉得有点可惜。其实影片一开始也暗示了一些东西的，不妨想想，莫杭治母亲去世不久，佩皮诺就拜访了莫杭治。佩皮诺是最后陪在马修身边的人，他的拜访一定是接受了马修的临终前的托付，说明马修也应该是刚离开人世不久。想到这里，多... (展开)
129 8 12回应 收起

> 更多影评 3552篇

添加新讨论

## 讨论区 · · · · · ·

每天上来看一遍有没有确定重映日期，这是我最近唯... | 来自曼多加尼 | 9 回应 | 2022-11-24 19:17:02
4K重制版定档12月2日 | 来自迷路的麋鹿 | 2 回应 | 2022-11-24 15:13:45
今天11月21号了 | 来自小猪乔治 | 7 回应 | 2022-11-24 14:41:33
海报好看，拉踩下隔壁 | 来自momo |  | 2022-11-24 14:40:12
这部应该不会有删减镜头吧 | 来自考༺༒༻ 拉本 | 1 回应 | 2022-11-24 13:53:46

> 去这部影片的讨论区（全部497条）

## 关于《放牛班的春天》的问题 · · · · · · ( 全部31个 )

- 皮埃尔为什么向马修扔墨水？ 5人回答
- 那个坏小孩后来要怎样？ 22人回答

> 全部31个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 我爱的文艺片 (有猫万事足)
- 电影中的美少年 (海棠一生)

## 谁在看这部电影 · · · · · ·

- 6HYLIRI
  1分钟前 看过
- 吃一口年糕
  1分钟前 想看
- 匿名用户
  2分钟前 想看

2300025人看过 / 415360人想看

订阅放牛班的春天的评论:
feed: rss 2.0